package Bundle::SDK::SIMON;

$VERSION = '1.00';

1;

__END__

=head1 NAME

Bundle::SDK::SIMON - CPAN Bundle for '10 Modules I Wouldn't Go Anywhere Without'

=head1 SYNOPSIS

C<perl -MCPANPLUS -e 'install Bundle::SDK::SIMON'>

=head1 CONTENTS

Bundle::CPAN

Bundle::LWP

Mail::Send

MLDBM

Date::Calc

DBI

Data::Dumper

POE

File::Spec

XML::Simple

=head1 DESCRIPTION

This bundle installs the 10 modules outlined in my popular "10 Modules I
Wouldn't Go Anywhere Without" talk, given at TPC 5 and YAPC 2002. I'd
highly recommend people who are beginning to use Perl modules to start
with this essential set, which I consider to be a reasonable "Perl SDK".

The talk notes are included in this distribution as F<modules.pod>

=head1 AUTHOR

Simon Cozens, C<simon@cpan.org>.
